<?php

namespace FiloBlu\LookProduct\Block\Product\ProductList;

/**
 * Catalog product related items block
 *
 * @SuppressWarnings(PHPMD.LongVariable)
 */
class Related extends \Magento\Catalog\Block\Product\ProductList\Related  {

    /**
     * @var \Magento\Framework\Url\Helper\Data
     */
    protected $urlHelper;

    /**
     * Product types
     *
     * @var array|null
     */
    private $productTypes;
    
    /**
     * @param \Magento\Catalog\Block\Product\Context $context
     * @param \Magento\Checkout\Model\ResourceModel\Cart $checkoutCart
     * @param \Magento\Catalog\Model\Product\Visibility $catalogProductVisibility
     * @param \Magento\Checkout\Model\Session $checkoutSession
     * @param \Magento\Framework\Module\Manager $moduleManager
     * @param array $data
     */
    public function __construct(
    \Magento\Catalog\Block\Product\Context $context, \Magento\Checkout\Model\ResourceModel\Cart $checkoutCart, \Magento\Catalog\Model\Product\Visibility $catalogProductVisibility, \Magento\Checkout\Model\Session $checkoutSession, \Magento\Framework\Module\Manager $moduleManager, array $data = [], \Magento\Framework\Url\Helper\Data $urlHelper
    ) {
        $this->urlHelper = $urlHelper;
        parent::__construct(
                $context, $checkoutCart, $catalogProductVisibility, $checkoutSession, $moduleManager
        );
    }

    /**
     * Get post parameters
     *
     * @param \Magento\Catalog\Model\Product $product
     * @return string
     */
    public function getAddToCartPostParams(\Magento\Catalog\Model\Product $product) {
        $url = $this->getAddToCartUrl($product);
        return [
            'action' => $url,
            'data' => [
                'product' => $product->getEntityId(),
                \Magento\Framework\App\ActionInterface::PARAM_NAME_URL_ENCODED =>
                $this->urlHelper->getEncodedUrl($url),
            ]
        ];
    }

    /**
     * Returns wishlist widget options
     *
     * @return array
     */
    public function getWishlistOptions() {
        return ['productType' => $this->getProductTypes()];
    }

    /**
     * Returns an array of product types
     *
     * @return array|null
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    private function getProductTypes() {
        if ($this->productTypes === null) {
            $this->productTypes = [];

            if ($this->getType() == "related-rule") {
                $productCollection = $this->getAllItems();
            } else {
                $productCollection = $this->getItems();
            }

            /** @var $product \Magento\Catalog\Model\Product */
            foreach ($productCollection as $product) {
                $productTypes[] = $product->getTypeId();
            }
            $this->productTypes = array_unique($productTypes);
        }

        return $this->productTypes;
    }

}
